<?php

use Phinx\Db\Adapter\MysqlAdapter;
use Phinx\Migration\AbstractMigration;

class AddProduitList extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this
            ->table("produit_list_type", ['id' => false, 'primary_key' => ["produit_list_type_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('produit_list_type_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('produit_list_type_nom', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'produit_list_type_id'])
            ->addColumn('produit_list_type_status', 'boolean', ['null' => false, 'limit' => MysqlAdapter::INT_TINY, 'precision' => 3, 'after' => 'produit_list_type_nom'])
            ->create();

        $this
            ->table("produit_list", ['id' => false, 'primary_key' => ["produit_list_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('produit_list_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('client_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'produit_list_id', 'signed' => false])
            ->addColumn('produit_list_type_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'client_id', 'signed' => false])
            ->addColumn('produit_list_nom', 'string', ['null' => false, 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'produit_list_type_id'])
            ->addColumn('produit_list_date_ajout', 'datetime', ['null' => false, 'after' => 'produit_list_nom'])
            ->addColumn('produit_list_date_modif', 'datetime', ['null' => false, 'after' => 'produit_list_date_ajout'])
            ->addColumn('produit_list_delete', 'boolean', ['null' => false, 'limit' => MysqlAdapter::INT_TINY, 'precision' => 3, 'after' => 'produit_list_date_modif'])
            ->addForeignKey('client_id', 'client', 'client_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('produit_list_type_id', 'produit_list_type', 'produit_list_type_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['client_id'], ['name' => "client_id", 'unique' => false])
            ->addIndex(['produit_list_type_id'], ['name' => "produit_list_type_id", 'unique' => false])
            ->create();

        $this
            ->table("produit_list_produit", ['id' => false, 'primary_key' => ["produit_list_produit_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('produit_list_produit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('produit_list_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'produit_list_produit_id', 'signed' => false])
            ->addColumn('produit_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'produit_list_id', 'signed' => false])
            ->addColumn('produit_attribut_id', 'integer', ['null' => true, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'produit_id', 'signed' => false])
            ->addColumn('produit_list_produit_qte', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'after' => 'produit_attribut_id'])
            ->addForeignKey('produit_list_id', 'produit_list', 'produit_list_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('produit_id', 'produit', 'produit_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addForeignKey('produit_attribut_id', 'produit_attribut', 'produit_attribut_id', array(
                'delete' => 'CASCADE',
                'update' => 'CASCADE'
            ))
            ->addIndex(['produit_list_id', 'produit_id', 'produit_attribut_id'], ['name' => "produit_list_id_2", 'unique' => true])
            ->addIndex(['produit_list_id'], ['name' => "produit_list_id", 'unique' => false])
            ->addIndex(['produit_id'], ['name' => "produit_id", 'unique' => false])
            ->addIndex(['produit_attribut_id'], ['name' => "produit_attribut_id", 'unique' => false])
            ->create();
    }
}
