<?php

use Phinx\Db\Adapter\MysqlAdapter;
use Phinx\Migration\AbstractMigration;

class AddAdresseType extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this
            ->table("adresse_type", ['id' => false, 'primary_key' => ["adresse_type_id"], 'engine' => "InnoDB", 'encoding' => "utf8", 'collation' => "utf8_general_ci", 'comment' => ""])
            ->addColumn('adresse_type_id', 'integer', ['null' => false, 'limit' => MysqlAdapter::INT_REGULAR, 'precision' => 10, 'identity' => 'enable', 'signed' => false])
            ->addColumn('adresse_type_nom', 'string', ['null' => false, 'default' => '', 'limit' => 255, 'collation' => "utf8_general_ci", 'encoding' => "utf8", 'after' => 'adresse_type_id'])
            ->create();

        $produit_list_type = array(
            array('adresse_type_id' => Adresse::TYPE_LIVRAISON, 'adresse_type_nom' => 'Livraison'),
            array('adresse_type_id' => Adresse::TYPE_FACTURATION, 'adresse_type_nom' => 'Facturation')
        );

        $this
            ->table('adresse_type')
            ->insert($produit_list_type)
            ->save();

        $this->table("adresse")
            ->addColumn("adresse_type_id", "integer", array("default" => Adresse::TYPE_LIVRAISON, 'signed' => false))
            ->addIndex(['adresse_type_id'], ['name' => "adresse_type_id", 'unique' => false])
            ->addForeignKey('adresse_type_id', 'adresse_type', 'adresse_type_id', array(
                'delete' => 'RESTRICT',
                'update' => 'RESTRICT'
            ))

            ->update();
    }
}
