<?php

namespace Controller;

use Application;
use Auth\AuthException;
use Boutique;
use Cms;
use Exception;
use Form\AddressForm;
use Form\Constraint\NotBlank;
use Form\Field;
use Form\ParrainageForm;
use Form\PasswordForm;
use Form\ProfileForm;
use Form\SavePanierForm;
use Mailer;
use Pays;
use Shopbydedi\Client;
use Shopbydedi\Panier;
use SimplePie;
use Texte;
use Breadcrumb;
use Adresse;
use BonAchat;
use Commande;
use Produit;
use Tools;
use Wishlist;
use Livraison;

use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/account", defaults = {"role" = "customer"})
 */
class AccountController extends Controller
{

    /**
     * @Route("/", name="compte")
     *
     * @return mixed
     */
    public function account()
    {
        $texte = new Texte();
        Breadcrumb::getInstance()->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $client = $this->getCurrentClient();
        $this->template->assign('client', $client->toArray());

        return $this->render('account/index.tpl');
    }

    /**
     * @Route("/modify", name="modif_compte", methods = { "GET" })
     *
     * @return mixed
     */
    public function modify()
    {
        $texte = new Texte();
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mon_profil', 'Mon profil'));

        $pays = new Pays();
        $client = $this->getCurrentClient();

        $tplVars = array();
        $tplVars['pays'] = $pays->get();
        $tplVars['civilite'] = $client->getCivilite();
        $tplVars['client'] = $client->toArray();
        $this->template->assign('page', 'modif_compte');

        return $this->render('account/modify.tpl', array_merge($this->getFlashAssign(array("error", "success", "post")),$tplVars));
    }

    /**
     * @Route("/modify", name="modif_compte_post", methods = { "POST" })
     *
     */
    public function modify_post()
    {
        $texte = new Texte();
        $post = $this->request->request->all();
        $session = $this->request->getSession();
        $flashBag = $session->getFlashBag();
        $form = new ProfileForm();

        if(!empty($post['client_ddn_Year']) && !empty($post['client_ddn_Month']) && !empty($post['client_ddn_Day'])) {
            $date = $post['client_ddn_Year'] . "-" . str_pad($post['client_ddn_Month'], 2, "0", STR_PAD_LEFT) . "-" . str_pad($post['client_ddn_Day'], 2, "0", STR_PAD_LEFT);
            $this->request->request->set('client_ddn',$date);
            $post['client_ddn'] = $date;
        }

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
        }

        if (!$flashBag->has('error')) {
            $client = $this->getCurrentClient();
            $post['client_id'] = $this->getCurrentClient()->client_id;

            if(!empty($post["client_referer"])) {
                $parrainId = $client->get(array("client_email" => $post["client_referer"]), "client_id");
                if(empty($parrainId)) {
                    $flashBag->add('error',
                        $texte->getOneOrCreate('errCreationClient',
                            'Une erreur lors la récupération du parrain est survenue. Veuillez re essayer.')
                    );
                } else {
                    $post["parrain_id"] = $parrainId;
                }
            }

            try {
                $client->update($post);
            } catch (\Exception $e) {
                error_log($e->getMessage());
                error_log($e->getTraceAsString());
                $flashBag->add('error', $texte->getOneOrCreate('nokModifCompte',
                    'Une erreur a empêché la mise à jour de votre compte.'));
            }
            $flashBag->add('success', $texte->getOneOrCreate('okModifCompte', 'Votre compte a été mis à jour'));
        } else {
            $flashBag->set('post', $post);
        }

        return $this->redirect($this->generateUrl('modif_compte'));
    }

    /**
     * @Route("/account/rollover", name="account_rollover")
     */
    public function rollover()
    {
        //@TODO: appeler la fonction qui sert à savoir si un client est connecté ou non
        $session = $this->request->getSession();
        if($session->get('client_id')){
            $connect = true;
            $customer = new Client((int)$_SESSION['client_id']);
            $this->template->assign(array(
                'customer' => $customer
            ));

        } else {
            $connect = false;
        }
        $this->template->assign('connect', $connect);

        return $this->response(
            $this->template->fetch('account/rollover.tpl')
        );
    }

    /**
     * @Route("/ba", name="compte_ba")
     */
    public function ba()
    {
        $texte = new Texte;
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_ba', "Mes bons d'achats"));

        $bonAchat = new BonAchat;
        $arrBon = $bonAchat->get(array(
            'client_id' => $this->getCurrentClient()->client_id,
        ));
        $this->template->assign('bon', $arrBon);

        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());

        $this->template->assign('page', 'ba');

        return $this->render('account/ba.tpl');
    }

    /**
     * @Route("/filleul", name="compte_filleul")
     */
    public function filleul()
    {
        $texte = new Texte();
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('filleul', 'Filleuls'));

        $filleul = new Client;
        $arrFilleul = $filleul->get(array('parrain_id' => $this->getCurrentClient()->client_id));

        return $this->render('account/filleul.tpl', array("filleuls" =>  $arrFilleul));
    }

    /**
     * @Route("/parrainage", name="compte_parrainage", methods = { "GET" })
     */
    public function parrainage()
    {
        $texte = new Texte();
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('parrainage', 'Parrainage'));
        return $this->render('account/parrainage.tpl', $this->getFlashAssign(array("error", "success", "post")));
    }

    /**
     * @Route("/parrainage", name="compte_parrainage_post", methods = { "POST" })
     */
    public function parrainage_post()
    {
        $form = new ParrainageForm();
        $flashBag = $this->getFlashBag();

        $client = $this->getCurrentClient();

        if($error = $form->handle($this->request)){
            $flashBag->add("error", $error);
        }

        if (!$flashBag->has('error')) {
            $mailer = new Mailer(Application::getEmailSender());
            $texte = new Texte();

            $indexes = array("femail1", "femail2", "femail3", "femail4", "femail5");
            $emails = array();
            foreach ($indexes as $idx) {
                if ($this->request->get($idx) != false && filter_var($this->request->get($idx), FILTER_VALIDATE_EMAIL) !== false) {
                    $emails[] = $this->request->request->get($idx);
                } elseif($this->request->get($idx) != false) {
                    $flashBag->add("error",
                        $texte->getOneOrCreate("emailInvalide", "Une des adresses email renseignée n'est pas valide."));
                    break;
                }
            }

            if ($flashBag->has("error") == false && !empty($emails)) {
                $tags = array();
                $tags["message"] = $this->request->request->get("message");
                $tags["link"] = substr(SITE_URL, 0, -1) . $this->generateUrl("login", array("email" => $client->client_email));
                foreach ($emails as $email) {
                    try {
                        $mailer->send("email_parrainage", array($email), $tags);
                    } catch(Exception $e){
                        $flashBag->add("error", $texte->getOneOrCreate("errSendMail",
                            "Une erreur s'est produite et a empêché l'envoi d'email, merci de ré-essayer plus tard."));
                        if(Tools::isDediServicesIp()) $flashBag->add("error", $e->getMessage());
                    }
                }
                $flashBag->add("success",
                    $texte->getOneOrCreate("parrMailSent",
                        "Les emails de parrainage ont été correctement envoyés"));
            }
        }

        return $this->redirect($this->generateUrl("compte_parrainage"));
    }

    /**
     * @Route("/address_book", name="compte_adresse", methods = { "GET" })
     */
    public function address_book()
    {
        $texte = new Texte();
        $pays = new Pays();
        $client = new Client();
        $adresse = new Adresse();
        $flashBag = $this->request->getSession()->getFlashBag();

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_adresses', 'Mes adresses'));

        $error = $flashBag->get('error', []);
        $success = $flashBag->get('success', []);
        $this->template->assign('error', $error);
        $this->template->assign('success', $success);

        $this->template->assign('pays', $pays->get());
        $this->template->assign('civilite', $client->getCivilite());
        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());

        $adresse->cleanAddress($this->getCurrentClient()->client_id);

        $arrAdresseLivraison = $adresse->get(array("client_id" => $curClient->client_id, 'adresse_type_id' => Adresse::TYPE_LIVRAISON));
        $this->template->assign('arrAdresse', $arrAdresseLivraison);

        $arrAdresseFacturation = $adresse->get(array("client_id" => $curClient->client_id, 'adresse_type_id' => Adresse::TYPE_FACTURATION));
        if (!empty($arrAdresseFacturation)) {
            $this->template->assign('arrAdresseFacturation', $arrAdresseFacturation[0]);
        }

        $this->template->assign('page', 'adresses');

        return $this->render('account/address_book.tpl');
    }

    /**
     * @Route("/address_edit", name="compte_adresse_edit", methods = { "GET" })
     */
    public function address_edit()
    {
        $texte = new Texte();
        $adresse = new Adresse();
        $pays = new Pays();
        $client = new Client();
        $flashBag = $this->request->getSession()->getFlashBag();
        $error = $flashBag->get('error', []);
        $success = $flashBag->get('success', []);
        $post = $flashBag->get('post', []);

        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());

        $idAdresse = $this->request->get('adresse_id');
        if (!empty($idAdresse)) {
            $this->template->assign('adresse_id', $idAdresse);
        }
        $arrAdresse = array();
        if (!empty($idAdresse)) {
            $arrAdresse = $adresse->get(array('client_id' => $this->getCurrentClient()->client_id, 'adresse_id' => $idAdresse));
            if (!empty($arrAdresse)) {
                $arrAdresse = $arrAdresse[0];
                $this->template->assign('adresse', $arrAdresse);
            } else {
                $origin = $this->request->get('origin', null);

                if(!null === $origin && $origin === 'panier'){
                    return $this->redirect($this->generateUrl('panier'));
                }

                return $this->redirect($this->generateUrl("compte_adresse"));
            }
        }

        if (!empty($arrAdresse)) {
            $title = $texte->getOneOrCreate('modification_adresse', "Modification d'une adresse");
        } else {
            $title = $texte->getOneOrCreate('ajout_adresse', "Ajout d'une nouvelle adresse");
        }

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($title);

        $this->template->assign("title", $title);
        $this->template->assign("pays", $pays->get());
        $this->template->assign('civilite', $client->getCivilite());

        return $this->render('account/address_book_id.tpl', compact('error', 'success', 'post'));
    }

    /**
     * @Route("/address_edit_post", name="compte_adresse_edit_post", methods = { "POST" })
     */
    public function compte_adresse_edit_post()
    {
        $texte = new Texte();
        $adresse = new Adresse();

        $flashBag = $this->request->getSession()->getFlashBag();
        $params = $this->request->request->all();

        $idAdresse = $this->request->get('adresse_id');

        $origin = $this->request->get('origin', null);

        if (!empty($idAdresse)) {
            $arrAdresse = $adresse->get(array('client_id' => $this->getCurrentClient()->client_id, 'adresse_id' => $idAdresse));
            if (empty($arrAdresse)) {
                return $this->redirect($this->generateUrl("compte_adresse"));
            }
        }

        $form = new AddressForm();

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
            $flashBag->set('post', $params);
        }

        if(!$flashBag->has("error")){
            if (!empty($idAdresse)) {
                $addr = new Adresse($params["adresse_id"]); // modification
            } else {
                $addr = new Adresse(); // ajout
            }
            $arrAdresse = $adresse->get(array('client_id' => $this->getCurrentClient()->client_id, 'adresse_type_id' => Adresse::TYPE_LIVRAISON));
            if (empty($arrAdresse)) {
                $params['adresse_default'] = 1;
            }
            $addr->hydrate($params);
            $addr->client_id = $this->getCurrentClient()->client_id;
            $idAdresse = $adresse->save($addr->toArray());

            if ($params["adresse_default"] != 0) {
                Tools::setDefault('adresse', 'client', $this->getCurrentClient()->client_id, 1, $idAdresse);
            }

            if ($idAdresse) {
                $flashBag->add("success", $texte->getOneOrCreate("succAddrChang", "Votre adresse a été modifiée."));
            } else {
                $flashBag->add("success", $texte->getOneOrCreate("succAddrAjout", "Votre adresse a été ajoutée."));
            }

            if($origin === 'coordonnees'){
                return $this->redirect($this->generateUrl("coordonnees"));
            }

            return $this->redirect($this->generateUrl("compte_adresse"));
        }

        $paramGet = array();
        if (!empty($idAdresse)) {
            $paramGet['adresse_id'] = $idAdresse;
        }

        if($origin === 'coordonnees'){
            return $this->redirect($this->generateUrl("coordonnees"));
        }

        return $this->redirect($this->generateUrl("compte_adresse_edit", $paramGet));
    }

    /**
     * @Route("/adresses_delete", name="adresses_delete", methods = { "POST" })
     */
    public function adresses_delete()
    {
        $texte = new Texte();
        $adresse = new Adresse();
        $adresseId = $this->request->get('adresse_id');
        $flashBag = $this->request->getSession()->getFlashBag();
        $client = $this->getCurrentClient();

        if (!empty($adresseId)) {
            $arrAdresse = $adresse->get(array('client_id' => $client->client_id, 'adresse_id' => $adresseId, 'adresse_type_id' => Adresse::TYPE_LIVRAISON));

            if(!empty($arrAdresse)){
                $adresse->delete(array('adresse_id' => $adresseId,'client_id' => $client->client_id));
                $flashBag->add("success", $texte->getOneOrCreate("succAddrDelete", "Votre adresse a été supprimée."));

                if (!empty($arrAdresse[0]['adresse_default'])) {
                    $arrAdresse = $adresse->get(array('client_id' => $client->client_id, 'adresse_type_id' => Adresse::TYPE_LIVRAISON));
                    if (!empty($arrAdresse)) {
                        Tools::setDefault('adresse', 'client', $client->client_id, 1, $arrAdresse[0]['adresse_id']);
                    }
                }
            }
        }

        return $this->redirect($this->generateUrl('compte_adresse'));
    }

    /**
     * @Route("/adresses_default", name="adresses_default", methods = { "GET" })
     */
    public function adresses_default()
    {
        $adresseId = $this->request->get('adresse_id');
        $adresse = new Adresse($adresseId);

        if(!empty($adresseId) && $adresse->client_id == $this->getCurrentClient()->client_id && $adresse->adresse_type_id == Adresse::TYPE_LIVRAISON){

            $defaultExpedition = $this->request->get('adresse_default');

            // est toujours a 1 si != null
            if($defaultExpedition != null) {
                Tools::setDefault('adresse','client',$this->getCurrentClient()->client_id,1,$adresseId);
                Panier::getInstance()->setAddressShipping($adresse);
            }
        }
        return $this->redirect($this->generateUrl('compte_adresse'));
    }

    /**
     * @Route("/save-cart", name="save_cart")
     */
    public function save_cart()
    {
        $json     = array();
        $form     = new SavePanierForm();
        $texte    = new Texte();
        $panier   = \Panier::getInstance();
        $flashBag = $this->getFlashBag();
        $post     = $this->request->request->all();

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
        }

        if (!$flashBag->has('error')) {
            $produitList = new \PanierSave();
            $produitList->saveFromPanier($panier,$this->request->get('panier_nom'));

            $flashBag->add("success", $texte->getOneOrCreate("save_panier_cree", "Votre panier a bien été enregistré. Vous pouvez le retrouver dans votre compte client."));
            $redirect = $this->generateUrl('panier');
            $json['redirect'] = $redirect;

            return $this->response($json);
        }

        $flashBag->set('post', $post);
        $flashes = $flashBag->all();
        $json['html'] = $this->template->fetch('popup/save_cart_content.tpl', $flashes);

        return $this->response($json);
    }

    /**
     * @Route("/saved-carts", name="saved_carts", methods = { "GET" })
     */
    public function saved_cart()
    {
        $session = $this->request->getSession();
        $flashBag = $session->getFlashBag();
        $flashes = $flashBag->all();
        $texte = new Texte;

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_paniers_sauvegardes', 'Mes paniers sauvegardés'));

        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());

        $this->template->assign('page', 'paniers');

        $produitList = new \PanierSave();
        $arrLists = $produitList->getListDetail(array('client_id' => $this->getCurrentClient()->client_id));
        $this->template->assign('arrLists', $arrLists);

        return $this->render('account/saved_carts.tpl', $flashes);
    }

    /**
     * @Route(
     *      path         = "/saved-cart/{id}",
     *      name         = "saved_carts_id",
     *      requirements = { "id" = "[0-9]+" })
     */
    public function saved_cart_id()
    {
        $produitList = new \PanierSave();
        $id = $this->request->get('id');

        $params = array(
            'client_id' => $this->getCurrentClient()->client_id,
            'produit_list_id' => $id
        );
        $arrList = $produitList->getListDetail($params);

        if (empty($arrList)){
            return $this->redirect($this->generateUrl('saved_carts'));
        }

        $texte = new Texte;
        $arrList = $arrList[0];

        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_paniers_sauvegardes', 'Mes paniers sauvegardés'), $this->generateUrl('saved_carts'));
        $bd->add($arrList['produit_list_nom']);

        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());
        $this->template->assign('page', 'paniers');
        $this->template->assign('arrList', $arrList);

        return $this->render('account/saved_carts_id.tpl');
    }

    /**
     * @Route(
     *      path         = "/saved-carts-delete/{id}",
     *      name         = "saved_carts_delete",
     *      requirements = { "id" = "[0-9]+" })
     */
    public function saved_cart_delete()
    {
        $produitList = new \PanierSave();
        $texte = new Texte();
        $session = $this->request->getSession();
        $flashBag = $session->getFlashBag();
        $id = $this->request->get('id');

        $params = array(
            'client_id' => $this->getCurrentClient()->client_id,
            'produit_list_id' => $id
        );
        $arrList = $produitList->getList($params);

        if (empty($arrList)){
            return $this->redirect($this->generateUrl('saved_carts'));
        }

        $produitList->produit_list_id = $arrList[0]['produit_list_id'];
        $produitList->delete();

        $flashBag->add('success', $texte->getOneOrCreate('okPanierSupprime', 'Panier supprimé avec succès.'));
        return $this->redirect($this->generateUrl('saved_carts'));
    }

    /**
     * @Route(
     *      path         = "/saved-carts-order/{id}",
     *      name         = "saved_carts_order",
     *      requirements = { "id" = "[0-9]+" })
     */
    public function saved_cart_order()
    {
        $texte = new Texte();
        $session = $this->request->getSession();
        $flashBag = $session->getFlashBag();
        $produitList = new \PanierSave();
        $panier   = Panier::getInstance();

        $id = $this->request->get('id');

        $params = array(
            'client_id' => $this->getCurrentClient()->client_id,
            'produit_list_id' => $id
        );
        $arrList = $produitList->getListDetail($params);

        if (empty($arrList)){
            return $this->redirect($this->generateUrl('saved_carts'));
        }

        $arrListProduits = $produitList->getProduitsDetail($arrList[0]['produit_list_id']);

        foreach($arrListProduits as $p){
            try {
                $produit = new Produit($p['produit_id']);
                $attribut = new \Attribut($p['produit_attribut_id']);
                $panier->addProduct($produit, $attribut, $p['produit_list_produit_qte']);
            } catch (Exception $e) {
            }
        }

        $flashBag->add('success', $texte->getOneOrCreate('panier_sauvegarde_commande', 'Les produits disponibles ont été ajouté à votre panier.'));

        return $this->redirect($this->generateUrl('panier'));
    }

    /**
     * @Route("/password", name="modif_password", methods = { "GET" })
     */
    public function modify_password()
    {
        $texte = new Texte;
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mon_mot_de_passe', 'Mon mot de passe'));

        $curClient = $this->getCurrentClient();
        $this->template->assign('client', $curClient->toArray());

        $this->template->assign('page', 'password');

        return $this->render('account/password.tpl', $this->getFlashAssign(array("error", "success", "post")));
    }

    /**
     * @Route("/password", name="modif_password_post", methods = { "POST" })
     */
    public function modify_password_post()
    {
        $client = new Client();
        $texte = new Texte();
        $flashBag = $this->request->getSession()->getFlashBag();
        $post = $this->request->request->all();
        $customer = $this->getCurrentClient();

        $form = new PasswordForm();

        if (!\Tools::passwordValidate($post["client_password_old"], $customer->client_password)) {
            $flashBag->add("error", $texte->getOneOrCreate("errPassActuel", "Le mot de passe actuel renseigné est invalide."));
        }

        if ($error = $form->handle($this->request)) {
            $flashBag->add("error", $error);
        }

        if(!$flashBag->has("error")){
            $customer->client_password = \Tools::encryptPassword($post["client_password"]);
            try {
                $client->update($customer->toArray());
                $flashBag->add("success", $texte->getOneOrCreate("succPassChang", "Votre mot de passe a été modifié."));
            } catch (Exception $e) {
                $flashBag->add("error",
                    $texte->getOneOrCreate("errPassChang", "Un problème a empêché la mise à jour de votre mot de passe. Veuillez contacter un administrateur"));
            }
        }

        if ($flashBag->has("error")) {
            $flashBag->set("post", $post);
        }

        return $this->redirect($this->generateUrl("modif_password"));
    }

    /**
     * @Route("/history", name="commande")
     */
    public function history()
    {
        $texte = new Texte;
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_commandes', 'Mes commandes'));

        $commande = new Commande;
        $arrCmd = $commande->get(array('client_id' => $this->getCurrentClient()->client_id));

        return $this->render('account/history.tpl', array("commandes" => $arrCmd));
    }

    /**
     * @Route(
     *      path         = "/history/{id}",
     *      name         = "commande_details",
     *      defaults     = { "id" = null },
     *      requirements = { "id" = "[0-9]+" })
     */
    public function history_id()
    {
        $id = $this->request->get('id');
        $commande = new Commande;
        list($arrCommande) = $commande->get(array('commande_id' => $id, 'client_id'=> $this->getCurrentClient()->client_id));

        if(empty($arrCommande)) {
            return $this->redirect($this->generateUrl('commande'));
        }

        $texte = new Texte;
        $bd = Breadcrumb::getInstance();
        $bd->add($texte->getOneOrCreate('mon_compte', 'Mon compte'));
        $bd->add($texte->getOneOrCreate('mes_commandes', 'Mes commandes'), $this->generateUrl('commande'));
        $bd->add($texte->getOneOrCreate('suivi_commande_numero', 'Suivi commande n°') . ' ' . $id);

        // reductions
        $totalReduction = 0;
        $c = new Commande($id);// todo : mixup with ^^
        $vouchers = $c->getReduction();
        if(!empty($vouchers)) {
            $totalReduction = array_sum(array_filter(Tools::extractValue("produit_prix", $vouchers)));
        }
        $this->template->assign("totalReduction", $totalReduction);

        $arrStatut = $commande->getHistory(array('commande_id' => $id));
        $arrProduit = $commande->getProduit(array('commande_id' => $id));

        // @TODO : Lien de suivi a ameliorer
        // recuperation du lien de suivi
        if(!empty($arrCommande['commande_livraison_colis'])) {
            $livraison = new Livraison;
            $arrLivraison = $livraison->get(array('livraison_code'=>$arrCommande['commande_livraison_code']));
            if(count($arrLivraison)>0) {
                $lienColis = str_replace('%COLIS%', $arrCommande['commande_livraison_colis'], $arrLivraison[0]['livraison_suivi']);
            } else {
                $lienColis = "";
            }
        }

        if(!empty($lienColis)) {
            $this->template->assign("lienColis", $lienColis);
        }

        $this->template->assign("commande", $arrCommande);
        $this->template->assign("statut", $arrStatut[0]);
        $this->template->assign("produit", $arrProduit);

        return $this->render('account/history_id.tpl');
    }

    /**
     * @Route("/sav", name="compte_sav", methods = { "GET" })
     */
    public function sav()
    {
        return $this->redirect($this->generateUrl('contact', ["origin" => "compte_sav"]));
    }

    /**
     * @Route(path = "/commande-pdf", name="compte_commande_pdf")
     */
    public function pdf()
    {
        $id = $this->request->get('commande_id');

        $commande = new Commande;
        list($arrCommande) = $commande->get(array('commande_id' => $id, 'client_id'=> $this->getCurrentClient()->client_id));
        $arrStatut = $commande->getHistory(array('commande_id' => $id));
        $arrProduit = $commande->getProduit(array('commande_id' => $id));
        $tplVars["commande"] = $arrCommande;
        $tplVars["statut"] = $arrStatut[0];
        $tplVars["produit"] = $arrProduit;
        $htmlContent = $this->render('account/commande_pdf.tpl', compact('tplVars'));
        $filename = 'United_equipement_commande_'.$id;

        return $this->renderPdf($htmlContent, $filename);
    }
}