<?php

namespace Shopbydedi;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Session\SessionInterface;
use Model;
use Boutique;
use SiteSQL;
use Query;
use Tools;
use Email;
use Adresse;
use DediException;
use Exception;
use Mailer;
use Texte;
use Application;

/**
 * Class Client
 * @package Shopbydedi
 *
 * @property integer $client_id
 * @property string $client_nom
 * @property string $client_prenom
 * @property string $civilite_nom_nom
 * @property string $adresse_rue
 * @property string $adresse_rue2
 * @property string $adresse_ville
 * @property string $adresse_cp
 * @property string $pays_nom_nom
 */
class Client extends Model
{
    const KEY_ATUOCONNECT = '!W1Li#35^Ime}';

    const STATUT_VISIBLE = 1;
    const STATUT_CACHE = 2;
    const STATUT_ATTENTE = 3;

    protected $table = 'client';

    public function __construct($id = null)
    {
        $this->extras['select'] = 'c.*, cn.*, a.*, c.client_id, c.civilite_id';

        $this->leftJoin[] = array(
            'civilite_nom',
            'AND',
            array('cn.civilite_id', 'c.civilite_id'),
            array('cn.langue_id', Boutique::getInstance()->getLangue()->id),
        );

        $this->leftJoin[] = array(
            'adresse',
            'AND',
            array('a.client_id', 'c.client_id'),
//            array('a.adresse_default', 1),// todo : remettre la limitation, cause des soucis quand le client n'a plus d'adresse par défaut
        );

        parent::__construct($id);
    }

    // recuperatio d'un client
    function get($formvars = array(), $champs = "") {

        $lgId = Boutique::getInstance()->getLangue()->id;

        $sql = "SELECT a.*, pn.*, c.client_id, c.civilite_id, cn.civilite_nom_nom, c.client_nom, c.client_prenom, c.client_ddn, c.client_email, c.client_telephone, c.client_fax, c.client_password, c.client_newsletter_id, c.langue_id, c.client_club_id, c.client_bon_plan_id ";
        $sql.=", c.boutique_id";
        $sql.=", DATE_FORMAT(c.client_date_ajout,'%d/%m/%Y') as date_inscription, p.client_email AS parrain_email";
        $sql.=", c.parrain_id as parrain_id";
        $sql.=", c.client_societe";
        if (!empty($formvars['client_email_search']))
            $sql.=", c.client_email AS client_email_search";
        $sql.=" FROM (client c)";
        $sql.=" LEFT JOIN civilite ci ON(c.civilite_id = ci.civilite_id)";
//        $sql.=" LEFT JOIN adresse a ON(c.client_id = a.client_id AND a.adresse_default = '1')";
        $sql.=" LEFT JOIN adresse a ON(c.client_id = a.client_id)";
        $sql.=" LEFT JOIN pays pa ON(a.pays_id = pa.pays_id)";
        $sql.=" LEFT JOIN civilite_nom cn ON (cn.civilite_id = c.civilite_id AND cn.langue_id = '" . $lgId . "')";
        $sql.=" LEFT JOIN pays_nom pn ON (pn.pays_id = pa.pays_id AND pn.langue_id = '" . $lgId . "')";
        $sql.=" LEFT JOIN client p ON (c.parrain_id = p.client_id)";
        $sql.=" WHERE c.client_statut_id = '1'";
        $sql.=" AND c.boutique_id = '".Boutique::getInstance()->id."'";

        if (!empty($formvars['client_id']))
            $sql.=" AND c.client_id = '" . $formvars['client_id'] . "'";
        if (!empty($formvars['client_email']))
            $sql.=" AND c.client_email = '" . trim($formvars['client_email']) . "'";

        if (!empty($formvars['client_nom']))
            $sql.=" AND c.client_nom LIKE '%" . $formvars['client_nom'] . "%'";
        if (!empty($formvars['client_prenom']))
            $sql.=" AND c.client_prenom LIKE '%" . $formvars['client_prenom'] . "%'";
        if (!empty($formvars['client_email_search']))
            $sql.=" AND c.client_email LIKE '%" . $formvars['client_email_search'] . "%'";

        if (!empty($formvars['client_password']))
            $sql.=" AND c.client_password = '" . $formvars['client_password'] . "'";
        if (!empty($formvars['parrain_id']))
            $sql.=" AND c.parrain_id = '" . $formvars['parrain_id'] . "'";
        if(!empty($formvars['auto_connexion']))
            $sql.=" AND MD5(CONCAT(c.client_id,'".Client::KEY_ATUOCONNECT."')) = '".$formvars['auto_connexion']."'";
        if (!empty($formvars['client_id_not']))
            $sql .= " AND c.client_id <> " . $formvars['client_id_not'];

        if (!empty($formvars['search']))
            $sql.=" AND (
                    c.client_email LIKE '%" . $formvars['search'] . "%' OR
                    c.client_nom LIKE '%" . $formvars['search'] . "%' OR
                    c.client_prenom LIKE '%" . $formvars['search'] . "%' OR
                    c.client_societe LIKE '%" . $formvars['search'] . "%'
                )";

        if (empty($champs)) {
            $this->sql->query($sql, SiteSQL::SQL_ALL, SiteSQL::SQL_ASSOC);
            return $this->sql->record;
        } else {
            $this->sql->query($sql, SiteSQL::SQL_INIT, SiteSQL::SQL_ASSOC);
            return $this->sql->record[$champs];
        }
    }

    // recuperation d'un filleul
    function getFilleul($formvars = array(), $champs = "") {

        $sql = "SELECT *";
        $sql.=" FROM client";
        $sql.=" WHERE 1";
        $sql.=" AND boutique_id = '".Boutique::getInstance()->id."'";
        if (!empty($formvars['client_id']))
            $sql.=" AND client_id = '" . $formvars['client_id'] . "'";
        if (!empty($formvars['parrain_email']))
        if (!empty($formvars['parrain_email']))
            $sql.=" AND client_email = '" . trim($formvars['parrain_email']) . "'";

        if (empty($champs)) {
            $this->sql->query($sql, SiteSQL::SQL_ALL, SiteSQL::SQL_ASSOC);
            return $this->sql->record;
        } else {
            $this->sql->query($sql, SiteSQL::SQL_INIT, SiteSQL::SQL_ASSOC);
            return $this->sql->record[$champs];
        }
    }

    // recuperation des civilites
    function getCivilite($formvars = array(), $champs = "") {

        $sql = "SELECT c.civilite_id, cn.civilite_nom_nom";
        $sql.=" FROM civilite c, civilite_nom cn";
        $sql.=" WHERE c.civilite_id = cn.civilite_id";
        $sql.=" AND cn.langue_id = '" . Boutique::getInstance()->getLangue()->id . "'";

        if (!empty($formvars['civilite_id']))
            $sql.=" AND c.civilite_id = '" . $formvars['civilite_id'] . "'";

        if (empty($champs)) {
            $this->sql->query($sql, SiteSQL::SQL_ALL, SiteSQL::SQL_ASSOC);
            return $this->sql->record;
        } else {
            $this->sql->query($sql, SiteSQL::SQL_INIT, SiteSQL::SQL_ASSOC);
            return $this->sql->record[$champs];
        }
    }


    public function add($formvars = array())
    {

        if (!isset($formvars['client_newsletter_id']))
            $formvars['client_newsletter_id'] = "0";
        if (!isset($formvars['client_club_id'])) {
            $formvars['client_club_id'] = "0";
            $formvars['client_bon_plan_id'] = "0";
        } else {
            $formvars['client_bon_plan_id'] = 1;
        }
        if (empty($formvars['boutique_id'])) {
            $formvars['boutique_id'] = Boutique::getInstance()->id;
        }

        Tools::escapeDataToSql($formvars);

        $sql = "INSERT INTO client SET";
        $sql .=" civilite_id = '" . $formvars['civilite_id'] . "'";
        if(isset($formvars['client_societe'])) {
            $sql .=", client_societe = '" . $formvars['client_societe'] . "'";
        }
        $sql .=", client_nom = '" . $formvars['client_nom'] . "'";
        $sql .=", client_prenom = '" . $formvars['client_prenom'] . "'";
        if(isset($formvars['client_ddn'])) {
            $sql .=", client_ddn = '" . $formvars['client_ddn'] . "'";
        }
        $sql .=", client_email = '" . trim($formvars['client_email']) . "'";
        $sql .=", client_telephone = '" . $formvars['client_telephone'] . "'";
        if(isset($formvars['client_fax'])) {
            $sql .=", client_fax = '" . $formvars['client_fax'] . "'";
        }
        if (!empty($formvars['client_password'])) {
            $sql .= ", client_password = '" . \Tools::encryptPassword($formvars['client_password']) . "'";
        }
        $sql .=", client_newsletter_id = '" . $formvars['client_newsletter_id'] . "'";
        $sql .=", client_statut_id = 1";
        $sql .=", client_date_ajout = NOW()";
        $sql .=", client_date_modif = NOW()";
        $sql .=", client_date_connexion = NOW()";
        $sql .=", client_nb_connexion = '1'";
        $sql .=", langue_id = '" . Boutique::getInstance()->getLangue()->id . "'";
        $sql .=", client_club_id = '" . $formvars['client_club_id'] . "'";
        $sql .=", client_bon_plan_id = '" . $formvars['client_bon_plan_id'] . "'";
        if (!empty($formvars['client_referer']))
            $sql .=", client_referer = '" . $formvars['client_referer'] . "'";
        if (!empty($formvars['parrain_id'])) {
            $sql .= ", parrain_id = '" . $formvars['parrain_id'] . "'";
        }
        $sql .=", boutique_id = '" . Boutique::getInstance()->id . "'";
        $this->sql->query($sql);

        $idClient = $this->sql->db->insert_id;

        if (empty($idClient)) {
            throw new DediException('error create customer');
        }

        // Ajout adresse
        $adresse = new Adresse;
        $formvars['adresse_libelle'] = $formvars['client_nom'] . ' ' . $formvars['client_prenom'];
        if (!empty($formvars['client_societe'])) {
            $formvars['adresse_societe'] = $formvars['client_societe'];
        }
        $formvars['adresse_nom'] = $formvars['client_nom'];
        $formvars['adresse_prenom'] = $formvars['client_prenom'];
        $formvars['client_id'] = $idClient;
        $formvars['adresse_telephone'] = $formvars['client_telephone'];
        $formvars['adresse_default'] = 1;

        // Adresse livraison
        $formvars['adresse_type_id'] = Adresse::TYPE_LIVRAISON;
        $idAdresse = $adresse->save($formvars);

        // Adresse facturation
        $formvars['adresse_default'] = 0;
        $formvars['adresse_type_id'] = Adresse::TYPE_FACTURATION;
        $idAdresse = $adresse->save($formvars);

        // Envoie mail
        $formvars['client_civilite'] = $this->getCivilite(array('civilite_id' => $formvars['civilite_id']), 'civilite_nom_nom');
        try {
            $mailer = new \Mailer(\Application::getEmailSender());
            $mailer->send("inscription_client",$formvars['client_email'], $formvars);
        } catch (Exception $e) {
            error_log($e->getMessage());
            error_log($e->getTraceAsString());
        }

        return $idClient;
    }

    /**
     * For update data client in table 'client' and 'adresse'
     *
     * @param array $data
     *
     * @throws DediException
     */
    public function update($data = array())
    {
        if (empty($data['client_id'])) {
            throw new DediException('require a client id');
        }

        $this->save($data);

        $adresse = new Adresse();
        $addr = $adresse->getDefault($data['client_id']);

        if (!$addr->isLoaded()) {
            throw new DediException('No default address for the client id');
        }

        $data['adresse_id'] = $addr->adresse_id;
        $this->sql->save('adresse', $data);
    }

    // mise a jour du mot de passe
    function updatePassword($formvars = array())
    {
        Tools::escapeDataToSql($formvars);
        $this->sql->beginTransaction();
        $sql = "UPDATE client SET";
        $sql .= " client_password = '" . \Tools::encryptPassword($formvars['client_password']) . "'";
        $sql .= ", client_date_modif = NOW()";
        $sql .= " WHERE 1";
        if (!empty($_SESSION['client_id']))
            $sql .= " AND client_id = '" . $_SESSION['client_id'] . "'";
        if (!empty($formvars['client_email']))
            $sql .= " AND client_email = '" . $formvars['client_email'] . "'";
        $sql .= " AND boutique_id = '" . Boutique::getInstance()->id . "'";

        $this->sql->query($sql);

        $modified = $this->sql->db->affected_rows;

        if ($modified != 1) {
            // nothing modified, end it
            $this->sql->db->rollback();
            $this->sql->endTransaction();
            throw new Exception("Password update failed.");
        } else {
            // validate modifications if everything was OK
            $this->sql->endTransaction();
        }
    }

    // mise a jour de la connexion
    function connexion($formvars = array()) {
        $sql = "UPDATE client SET";
        $sql.=" client_date_connexion = NOW()";
        $sql.=", client_nb_connexion = client_nb_connexion + 1";
        $sql.=" WHERE client_id = '" . $formvars['client_id'] . "'";
        $sql.= " AND boutique_id = '".Boutique::getInstance()->id."'";
        $this->sql->query($sql);
    }

    // Generation d'un nouveau mot de passe
    function mailPassword($formvars = array())
    {
        $formvars["client_password"] = $this->passwordCreate(8);
        list($arrClient) = $this->get(array('client_email' => $formvars['client_email']));
        $arrClient['client_password'] = $formvars["client_password"]; // new password

        $to = array($arrClient["client_email"] => $arrClient["client_prenom"] . " " . $arrClient["client_nom"]);
        $tags = $arrClient;

        try {
            $this->updatePassword($formvars); // may throw exception on error
            $mailer = new Mailer(Application::getEmailSender());
            $mailer->send("email_reset_password", $to, $tags);
        } catch (Exception $e) {
            $flashBag = Application::getCurrentRequest()->getSession()->getFlashBag();
            $texte = new Texte();
            $flashBag->add("error", $texte->getOneOrCreate("errResetPass",
                "Une erreur s'est produite durant la réinitialisation de votre mot de passe, veuillez ré-essayer plus tard."));
            if(Tools::isDediServicesIp()) $flashBag->add("error", $e->getMessage());
        }
    }

    // Creer un password aleatoire
    function passwordCreate($length, $type = 'mixed') {

        if (($type != 'mixed') && ( $type != 'chars') && ( $type != 'digits'))
            return false;
        $rand_value = '';

        while (strlen($rand_value) < $length) {

            if ($type == 'digits') {
                $char = \Tools::getRand(0, 9);
            } else {
                $char = chr(\Tools::getRand(0, 255));
            }

            if ($type == 'mixed') {
                if (preg_match('/^[a-z0-9]$/i', $char))
                    $rand_value .= $char;
            } elseif ($type == 'chars') {
                if (preg_match('/^[a-z]$/i', $char))
                    $rand_value .= $char;
            } elseif ($type == 'digits') {
                if (preg_match('/^[0-9]$/', $char))
                    $rand_value .= $char;
            }
        }
        return $rand_value;
    }

    function deleteNewsletter($email) {

        // suppression dans le compte client
        $sql = "UPDATE client SET";
        $sql.=" client_newsletter_id = '0'";
        $sql.=", client_date_modif = NOW()";
        $sql.=" WHERE client_email = '" . $email . "'";
        $sql.=" AND boutique_id = '".Boutique::getInstance()->id."'";
        $this->sql->query($sql);

        // suppression dans la table newsletter
        $sql = "DELETE FROM newsletter WHERE newsletter_email = '" . $email . "'";
        $this->sql->query($sql);
    }

    /**
     * @param \Symfony\Component\HttpFoundation\Session\SessionInterface $session
     * @param $arrClient
     * @param array $paramOpt
     *
     * @return void
     */
    public function setSession(SessionInterface $session, $arrClient, $paramOpt = array())
    {

        $param = array('client_id', 'client_nom', 'client_prenom', 'client_email');
        $param = array_merge($param, $paramOpt);

        foreach($param as $p){
            if(!empty($arrClient[$p])){
                $session->set($p, $arrClient[$p]);
            }
        }
    }

    /**
     * @param \Symfony\Component\HttpFoundation\Session\SessionInterface $session
     * @param array $paramOpt
     *
     * @return void
     */
    function destroySession(SessionInterface $session, $paramOpt = array()){
        Client::destroyCookieStayLogin();

        $param = array('client_id', 'client_nom', 'client_prenom', 'client_email');
        $param = array_merge($param, $paramOpt);

        foreach($param as $p){
            if($session->has($p)){
                $session->remove($p);
            }
        }

        Panier::getInstance()
            ->initCustomer()
            ->initAddresses()
            ->initRelay();
    }

    static public function setCookieStayLogin() {
        $nbJours = 30;

        $addrIp = $_SERVER['REMOTE_ADDR'];
        $data = md5(Client::KEY_ATUOCONNECT . $addrIp . $_SESSION['client_id']);

        setcookie('auto_connect', $data, (time() + (60 * 60 * 24 * $nbJours)), '/');
    }

    static public function loadCookieStayLogin() {
        $client = new Client;

        $autoConnect = SiteSQL::getInstance()->db->escape_string($_COOKIE['auto_connect']);
        $arrClient = $client->get(array('auto_connexion_cookie' => $autoConnect));
        if (!empty($arrClient[0]['client_id'])) {
            $client->setSession($arrClient[0]);
        }
    }

    static public function destroyCookieStayLogin() {
        if(!empty($_COOKIE['auto_connect'])){
            setcookie("auto_connect", "", time() - 3600, '/');
        }
    }

    public function enable($client_id){
        $this->updateStatut($client_id, self::STATUT_VISIBLE);
    }

    public function disable($client_id){
        $this->updateStatut($client_id, self::STATUT_CACHE);
    }

    protected function updateStatut($client_id, $statut_id){
        $sql = "UPDATE client SET client_statut_id = '".$statut_id."' WHERE client_id = '".$client_id."'";
        $this->sql->query($sql);

        return $this->sql->db->affected_rows;
    }

    // Pour la relance 7 jours apres l'inscription d'un client n'ayant encore rien commande
    function getClient7j($formvars = array(), $champs = "") {

        $sql = "SELECT *";
        $sql.=" FROM client";
        $sql.=" WHERE ADDDATE(DATE_FORMAT(client_date_ajout, '%Y-%m-%d'), 2) = CURDATE()";
        $sql.=" AND client_id NOT IN (SELECT client_id FROM commande)";

        if (empty($champs)) {
            $this->sql->query($sql, SiteSQL::SQL_ALL, SiteSQL::SQL_ASSOC);
            return $this->sql->record;
        } else {
            $this->sql->query($sql, SiteSQL::SQL_INIT, SiteSQL::SQL_ASSOC);
            return $this->sql->record[$champs];
        }
    }

    public function getRole($clientId = null)
    {
        if (is_null($clientId) && empty($this->client_id)) {
            throw new DediException('no client_id for getRole()');
        }

        if (is_null($clientId)) {
            $clientId = $this->client_id;
        }

        $query = new Query();
        $query->select()->from('client_role')
            ->innerJoin('role', 'cr.role_id', 'r.role_id')
            ->where('client_id', $clientId);

        return $this->sql->getAll($query->build());
    }

    public function hasRole($roleCode, $clientId = null)
    {
        if (is_null($clientId) && empty($this->client_id)) {
            throw new DediException('no client_id for hasRole()');
        }

        if (is_null($clientId)) {
            $clientId = $this->client_id;
        }

        $query = new Query();
        $query->select()->from('client_role')
            ->innerJoin('role', 'cr.role_id', 'r.role_id')
            ->where('client_id', $clientId)
            ->where('role_code', $roleCode);

        $result = $this->sql->getOne($query->build());

        return (!empty($result));
    }


    /*
     * Constraint callback, behavior is very specific.
     * Only check if a client is registered with given email
     */
    public static function mailIsUsed($email, Request $request)
    {
        // only search if param is not empty, other constraints will handle the rest
        if (empty($email)) return true;
        $client = new Client();
        $found = $client->getOne(array("client_email" => $email));
        return !empty($found);
    }

    /*
     * Constraint callback, behavior is very specific.
     * Only check if a given email address is free before registering
     */
    public static function mailIsFree($email, Request $request)
    {
        // only search if it's not empty, other constraints will handle the rest
        if (empty($email)) return true;

        $params = array("client_email" => $email);
        $session = $request->getSession();
        if ($session->has('client_id')) {
            $params['client_id_not'] = $session->get('client_id');
        }

        $client = new Client();
        $found = $client->get($params);
        return empty($found);
    }

    /*
     * Constraint callback, behavior is very specific.
     * Check if we have : either a company of firstname and lastname
     */
    public static function companyOrName($company, Request $request)
    {
        $prenom = $request->request->get("client_prenom");
        $nom = $request->request->get("client_nom");
        if (empty($company) && !empty($prenom) && !empty($nom)) {
            return true;
        } else if (!empty($company)) {
            return true;
        }
        return false;
    }

    /**
     * @param array $formvars
     * @return array|null
     */
    public function getAutoComplete($formvars = array())
    {

        $sql = "SELECT c.client_id, c.client_nom, c.client_prenom";
        $sql .= " FROM (client c)";
        if (!empty($formvars['search'])) {
            $sql.=" WHERE (
                c.client_nom LIKE '%" . $formvars['search'] . "%'
                OR c.client_prenom LIKE '%" . $formvars['search'] . "%'
                OR c.client_id LIKE '%" . $formvars['search'] . "%'
            )";
        }
        return $this->sql->getAll($sql);
    }

    /**
     * @param $clientId
     * @return array
     * @throws Exception
     */
    public function getCookieConsent($clientId)
    {
        $cookieClient = new \ClientCookie();
        return $cookieClient->getByClientId($clientId);
    }
}