<?php

/**
 * Class Texte
 */
class Texte
{

    const DEFAULT_CAT_ID = 1;

    /**
     * @var array
     */
    protected static $allTexte = array();

    /**
     * @var SiteSQL
     */
    protected $sql;

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->sql = SiteSQL::getInstance();
    }

    /**
     * @param array $formvars
     * @param string $champs
     * @return array|string
     *
     * recuperation des infos de texte
     */
    public function get($formvars = array(), $champs = "")
    {

        $sql = "SELECT *";
        $sql.=" FROM (edition e, edition_nom en)";
        $sql.=" WHERE e.edition_id = en.edition_id";
        $sql.=" AND en.langue_id = '" . Boutique::getInstance()->getLangue()->id . "'";

        if (!empty($formvars['edition_id']))
            $sql.=" AND e.edition_id = '" . $formvars['edition_id'] . "'";
        if (!empty($formvars['edition_nom']))
            $sql.=" AND e.edition_nom = '" . $formvars['edition_nom'] . "'";
        if (!empty($formvars['liste_edition_nom']))
            $sql.=" AND e.edition_nom IN ('" . $formvars['liste_edition_nom'] . "')";

        if (empty($champs)) {
            return $this->sql->getAll($sql);
        } else {
            $result = $this->sql->getOne($sql);
            $res = ""; // can break ajax if no check
            if(!empty($result[$champs])) $res = $result[$champs];
            return $res;
        }
    }

    /**
     * @param $edition_nom
     * @param bool $replaceTag
     * @param array $tags
     * @return mixed
     *
     * recuperation d'un texte avec remplacement des tags ou pas
     */
    public function getOne($edition_nom, $replaceTag = true, $tags = array())
    {
        if(!isset(self::$allTexte[$edition_nom])) {
            $ed = $this->get(array('edition_nom' => $edition_nom));
            if (empty($ed)) {
                return null;
            }
            self::$allTexte[$edition_nom] = $ed[0]['edition_nom_nom'];
        }

        if ($replaceTag == true) {
            $texte = $this->replaceTag(self::$allTexte[$edition_nom], $tags);
            // Tags sup
            if (!empty($tags)) {
                foreach ($tags as $key => $value) {
                    $texte = $this->replaceIfTag(mb_strtoupper($key), $value, $texte);
                }
            }

            return $texte;
        } else {
            return self::$allTexte[$edition_nom];
        }
    }

    /**
     * @param $key
     * @param $value
     * @return mixed
     */
    public function getOneOrCreate($key, $value, $category = null)
    {
        $foundText = $this->getOne($key, false);

        // we've got something, return it
        if (null !== $foundText) {
            return $foundText;
        }

        // insert trad in DB
        if (Langue::DEFAULT_LANGUE_ID == Boutique::getInstance()->getLangue()->id) {

            $categorieId = self::DEFAULT_CAT_ID;

            if (!empty($category)) {
                $category = ucfirst($category);
                $query = new Query();
                $query->select()
                    ->from('edition_categorie')
                    ->where('edition_categorie_nom', $category);

                $arrCategorie = $this->sql->getOne($query->build());
                if (!empty($arrCategorie)) {
                    $categorieId = $arrCategorie['edition_categorie_id'];
                } else {
                    $categorieId = $this->sql->save('edition_categorie', array('edition_categorie_nom' => $category));
                }
            }

            $eId = $this->add(array(
                'edition_categorie_id' => $categorieId,
                'edition_nom' => $key,
                'edition_nom_nom' => $value,
                'langue_id' => Langue::DEFAULT_LANGUE_ID,
            ));

            // update our array
            self::$allTexte[$key] = $value;
        }

        return $value;
    }

    /**
     * @return array
     * @throws Exception
     */
    public function getAll()
    {

        $query = new Query();
        $query->select()
            ->from('edition')
            ->leftJoin(
                'edition_nom',
                'AND',
                array('e.edition_id', 'en.edition_id'),
                array('en.langue_id', Boutique::getInstance()->getLangue()->id)
            )
        ;

        $results = $this->sql->getAll($query->build());

        foreach ($results as $value) {
            self::$allTexte[$value['edition_nom']] = $this->replaceTag($value['edition_nom_nom']);
        }

        return self::$allTexte;
    }

    public static function setAll($allTextes)
    {
        self::$allTexte = $allTextes;
    }

    /**
     * @param $arrTxt
     * @return array
     */
    public function getListe($arrTxt)
    {
        if (!empty($arrTxt)) {
            $listeTxt = array();
            $arrTexte = $this->get(array('liste_edition_nom' => implode("','", $arrTxt)));
            foreach ($arrTexte as $txt) {
                $listeTxt[$txt['edition_nom']] = $txt['edition_nom_nom'];
            }
            return $listeTxt;
        }
    }

    /**
     * @param array $formvars
     * @return mixed
     * @throws Exception
     */
    public function add($formvars = array())
    {

        $q = new Query();
        $q->select()
            ->from('edition')
            ->where('edition_nom', $formvars['edition_nom'])
        ;

        $ed = $this->sql->getOne($q->build());

        if (empty($ed)) {
            $edId = $this->sql->save('edition', array(
                'edition_categorie_id' => $formvars['edition_categorie_id'],
                'edition_nom' => $formvars['edition_nom'],
            ));
        } else {
            $edId = $ed['edition_id'];
        }


        if (!empty($edId)) {
            $this->sql->save('edition_nom', array(
                'edition_id' => $edId,
                'edition_nom_nom' => $formvars['edition_nom_nom'],
                'langue_id' => $formvars['langue_id'],
            ));
        }

        return $edId;
    }

    /**
     * @param $text
     * @param array $tags
     * @return mixed
     */
    public function replaceTag($text, $tags = array())
    {

        $search = array();
        $replace = array();

        if (defined('SITE_NAME') == false) {
            define('SITE_NAME', Boutique::getInstance()->nom);
        }

        // Gestion des constantes
        array_push($search, '%SITE_NAME%');
        array_push($replace, SITE_NAME);
        array_push($search, '%SITE_URL%');
        array_push($replace, SITE_URL);

        // Gestion des tags
        if (!empty($tags)) {
            foreach ($tags as $key => $value) {
                if (is_array($value)) {
                    $text = $this->replaceTag($text, $value);
                } else {
                    array_push($search, '%' . strtoupper($key) . '%');
                    array_push($replace, $value);
                }
            }
        }

        return str_replace($search, $replace, $text);
    }

    /**
     * @param $tag
     * @param $value
     * @param $txt
     * @return mixed
     */
    public function replaceIfTag($tag, $value, $txt)
    {

        if (empty($value)) {
            $txt = preg_replace("/%IF_" . $tag . "%(.)*%IF_" . $tag . "%/s", "", $txt);
        } else {
            if (is_array($value)) {
                foreach ($value as $val) {
                    $txt = $this->replaceIfTag($tag, $val, $txt);
                }
            } else {
                $txt = str_replace("%IF_" . $tag . "%", '', $txt);
                $txt = str_replace("%" . $tag . "%", $value, $txt);
            }
        }

        return $txt;
    }

    /**
     * Transforme un code html en txt non formaté
     *
     * @param $html
     * @return mixed|string
     */
    public function htmlToTxt($html)
    {
        $txt = str_replace(array('<br/>', '<br>', '<br />'), "\n", $html);
        $txt = strip_tags($txt);
        $trans = array_flip(get_html_translation_table(HTML_ENTITIES));
        // cas particulier
        $trans['&#39;'] = "'";
        $trans['&rsquo;'] = "'";
        $trans['&oelig;'] = "oe";

        $txt = strtr($txt, $trans);

        return $txt;
    }
}
